@@ -1,22 +1,26 @@
+import os
 import argparse
 import pytest
 
-import dijkstra_alg
+
+from dijkstra_alg import __path__ as path
 from .dijkstra import dijkstra
 from .is_valid_input import is_valid
 
 
-
 def main():
     parser = argparse.ArgumentParser(description='Кратчайший путь между '
                                                  'узлами графа по алгоритму дейкстры')
     parser.add_argument('-v', '--variant', dest='variant', default='gui',
                         help='Вариант работы программы, '
-                             'где gui - запуск программы, pytest - '
-                             'Вывод результатов тестов pytest')
+                             'где gui - запуск программы, '
+                             'pytest - Вывод результатов тестов pytest,'
+                             'doctest - Вывод результатов теста doctest')
     args = parser.parse_args()
     if args.variant == 'pytest':
-        pytest.main([dijkstra_alg.__path__[0] + r"\tests\test_dijkstra.py"])
+        pytest.main([path[0] + r"\tests\test_dijkstra.py"])
+    elif args.variant == 'doctest':
+        print(os.system(f'python -m doctest -v {path[0]}\\dijkstra.py'))
     elif args.variant == 'gui':
         while (
                 info := input(
